import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread2";
var _excluded = ["chart", "chartRef", "data", "class", "style", "onReady"];
import { createVNode as _createVNode } from "vue";
import isEmpty from 'lodash/isEmpty';
import isEqual from 'lodash/isEqual';
import { computed, defineComponent, onBeforeUnmount, onMounted, ref, useAttrs, watch } from 'vue';
var BaseChart = defineComponent({
  inheritAttrs: false,
  name: 'BaseChart',
  setup: function setup(props, ctx) {
    var plotRef = ref(null);
    var containerRef = ref(null);
    var attrs = useAttrs();
    var attrConfig = computed(function () {
      return _objectSpread(_objectSpread({}, attrs), props);
    });
    var chartData = computed(function () {
      return attrConfig.value.data || [];
    });
    var chartConfig = computed(function () {
      var _attrConfig$value = attrConfig.value,
        chart = _attrConfig$value.chart,
        chartRef = _attrConfig$value.chartRef,
        data = _attrConfig$value.data,
        className = _attrConfig$value.class,
        style = _attrConfig$value.style,
        onReady = _attrConfig$value.onReady,
        config = _objectWithoutProperties(_attrConfig$value, _excluded);
      return config;
    });
    onMounted(function () {
      /* istanbul ignore else */
      if (containerRef.value) {
        var _attrConfig$value2 = attrConfig.value,
          Chart = _attrConfig$value2.chart,
          onReady = _attrConfig$value2.onReady,
          chartRef = _attrConfig$value2.chartRef;
        var plot = new Chart(containerRef.value, _objectSpread({
          data: chartData.value
        }, chartConfig.value));
        plot.render();
        if (chartRef) {
          chartRef.value = plot;
        }
        plotRef.value = plot;
        onReady === null || onReady === void 0 || onReady(plot);
      }
    });
    onBeforeUnmount(function () {
      /* istanbul ignore else */
      if (plotRef.value) {
        plotRef.value.destroy();
      }
    });
    watch(chartData, function (data, oldData) {
      /* istanbul ignore else */
      if (plotRef.value) {
        if (isEmpty(oldData)) {
          plotRef.value.update(_objectSpread({
            data: data
          }, chartConfig.value));
          plotRef.value.render();
        } else {
          plotRef.value.changeData(data);
        }
      }
    });
    watch(chartConfig, function (config, oldConfig) {
      /* istanbul ignore else */
      if (plotRef.value) {
        if (!isEqual(config, oldConfig)) {
          plotRef.value.update(_objectSpread({
            data: chartData.value
          }, config));
        }
      }
    });
    return function () {
      return _createVNode("div", {
        "ref": containerRef,
        "class": props.class,
        "style": props.style
      }, null);
    };
  }
});
export default BaseChart;